@@ -1,6 +1,7 @@
 """Application."""
 from __future__ import annotations
 
+import itertools
 import logging
 import os
 from functools import lru_cache
@@ -13,7 +14,7 @@ from rich.table import Table
 from ansiblelint import formatters
 from ansiblelint._mockings import _perform_mockings
 from ansiblelint.color import console, console_stderr, render_yaml
-from ansiblelint.config import PROFILES
+from ansiblelint.config import PROFILES, get_version_warning
 from ansiblelint.config import options as default_options
 from ansiblelint.constants import RULE_DOC_URL, SUCCESS_RC, VIOLATIONS_FOUND_RC
 from ansiblelint.errors import MatchError
@@ -84,7 +85,7 @@ class App:
         # If run under GitHub Actions we also want to emit output recognized by it.
         if os.getenv("GITHUB_ACTIONS") == "true" and os.getenv("GITHUB_WORKFLOW"):
             formatter = formatters.AnnotationsFormatter(self.options.cwd, True)
-            for match in matches:
+            for match in itertools.chain(fatal_matches, ignored_matches):
                 console.print(formatter.format(match), markup=False, highlight=False)
 
     def count_results(self, matches: list[MatchError]) -> SummarizedResults:
@@ -193,17 +194,23 @@ warn_list:  # or 'skip_list' to silence them completely
                 "because 'yaml' is in 'skip_list'."
             )
 
+        if mark_as_success and summary.failures and not self.options.progressive:
+            mark_as_success = False
+
         if not self.options.quiet:
             console_stderr.print(render_yaml(msg))
-            self.report_summary(summary, changed_files_count, files_count)
+            self.report_summary(
+                summary, changed_files_count, files_count, is_success=mark_as_success
+            )
 
-        if not self.options.strict and (mark_as_success or not summary.failures):
-            return SUCCESS_RC
-        return VIOLATIONS_FOUND_RC
+        return SUCCESS_RC if mark_as_success else VIOLATIONS_FOUND_RC
 
-    @staticmethod
     def report_summary(  # pylint: disable=too-many-branches,too-many-locals
-        summary: SummarizedResults, changed_files_count: int, files_count: int
+        self,
+        summary: SummarizedResults,
+        changed_files_count: int,
+        files_count: int,
+        is_success: bool,
     ) -> None:
         """Report match and file counts."""
         # sort the stats by profiles
@@ -269,10 +276,10 @@ warn_list:  # or 'skip_list' to silence them completely
             console_stderr.print(table)
             console_stderr.print()
 
-        if summary.failures:
-            msg = "[red][bold]Failed[/][/] after "
-        else:
+        if is_success:
             msg = "[green]Passed[/] with "
+        else:
+            msg = "[red][bold]Failed[/][/] after "
 
         if summary.passed_profile:
             msg += f"[bold]{summary.passed_profile}[/] profile"
@@ -284,6 +291,13 @@ warn_list:  # or 'skip_list' to silence them completely
             msg += f", and fixed {summary.fixed} issue(s)"
         msg += f" on {files_count} files."
 
+        # on offline mode and when run under pre-commit we do not want to
+        # check for updates.
+        if not self.options.offline and os.environ.get("PRE_COMMIT", "0") != "1":
+            version_warning = get_version_warning()
+            if version_warning:
+                msg += f"\n{version_warning}"
+
         console_stderr.print(msg)
 
 
@@ -313,13 +327,25 @@ def _sanitize_list_options(tag_list: list[str]) -> list[str]:
     return sorted(set(tags))
 
 
-@lru_cache(maxsize=1)
-def get_app(offline: bool = False) -> App:
-    """Return the application instance."""
+@lru_cache
+def get_app() -> App:
+    """Return the application instance, caching the return value."""
+    offline = default_options.offline
     app = App(options=default_options)
     # Make linter use the cache dir from compat
     default_options.cache_dir = app.runtime.cache_dir
 
-    app.runtime.prepare_environment(install_local=True, offline=offline)
+    role_name_check = 0
+    if "role-name" in app.options.warn_list:
+        role_name_check = 1
+    elif "role-name" in app.options.skip_list:
+        role_name_check = 2
+
+    # mocking must happen before prepare_environment or galaxy install might
+    # fail.
     _perform_mockings()
+    app.runtime.prepare_environment(
+        install_local=True, offline=offline, role_name_check=role_name_check
+    )
+
     return app
